/*
 * Board
 */
.blue .cg-board-wrap {
  background-image: url(images/board/blue.svg);
}

.merida .cg-board-wrap piece.pawn.white {
  background-image: url('images/pieces/merida/wP.svg');
}
.merida .cg-board-wrap piece.bishop.white {
  background-image: url('images/pieces/merida/wB.svg');
}
.merida .cg-board-wrap piece.knight.white {
  background-image: url('images/pieces/merida/wN.svg');
}
.merida .cg-board-wrap piece.rook.white {
  background-image: url('images/pieces/merida/wR.svg');
}
.merida .cg-board-wrap piece.queen.white {
  background-image: url('images/pieces/merida/wQ.svg');
}
.merida .cg-board-wrap piece.king.white {
  background-image: url('images/pieces/merida/wK.svg');
}
.merida .cg-board-wrap piece.pawn.black {
  background-image: url('images/pieces/merida/bP.svg');
}
.merida .cg-board-wrap piece.bishop.black {
  background-image: url('images/pieces/merida/bB.svg');
}
.merida .cg-board-wrap piece.knight.black {
  background-image: url('images/pieces/merida/bN.svg');
}
.merida .cg-board-wrap piece.rook.black {
  background-image: url('images/pieces/merida/bR.svg');
}
.merida .cg-board-wrap piece.queen.black {
  background-image: url('images/pieces/merida/bQ.svg');
}
.merida .cg-board-wrap piece.king.black {
  background-image: url('images/pieces/merida/bK.svg');
}
