{% extends 'agadmator/base.html' %}

{% block content %}
  {% include 'agadmator/_channel_media_large.html' %}


  <h2>Recent Videos</h2>
  <div class="row">
    {% for video in videos %}
  {% include 'agadmator/_video_card.html' %}
  {% endfor %}
  </div>

{% endblock content %}