# Generated by Django 2.1.3 on 2018-11-05 16:35

from django.db import migrations
from agadmator.models import Video


def populate_values(apps, schema_editor):

    for vid in Video.objects.all():
        vid.white_name = vid.get_white_name
        vid.white_slug = vid.get_white_slug
        vid.black_name = vid.get_black_name
        vid.black_slug = vid.get_black_slug
        vid.tournament_id = vid.get_tournament_id
        vid.tournament_name = vid.get_tournament_name
        vid.year = vid.get_year
        vid.save()


class Migration(migrations.Migration):
    dependencies = [
        ('agadmator', '0004_auto_20181105_1628'),
    ]

    operations = [
        migrations.RunPython(
            populate_values, reverse_code=migrations.RunPython.noop
        )
    ]
