# Generated by Django 2.1.3 on 2018-11-05 07:07

import django.contrib.postgres.fields.jsonb
import django.contrib.postgres.indexes
import django.contrib.postgres.search
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Video',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('youtube_id', models.CharField(blank=True, db_index=True, max_length=100)),
                ('title', models.CharField(blank=True, max_length=500)),
                ('time_updated', models.DateTimeField(auto_now=True)),
                ('time_published', models.DateTimeField(blank=True, db_index=True, null=True)),
                ('date_played', models.DateField(blank=True, db_index=True, null=True)),
                ('description', models.TextField(blank=True)),
                ('data', django.contrib.postgres.fields.jsonb.JSONField(blank=True, default=dict)),
                ('chessgames_id', models.BigIntegerField(blank=True, db_index=True, null=True)),
                ('search_vector', django.contrib.postgres.search.SearchVectorField(null=True)),
            ],
            options={
                'verbose_name': 'Video',
                'verbose_name_plural': 'Videos',
            },
        ),
        migrations.AddIndex(
            model_name='video',
            index=django.contrib.postgres.indexes.GinIndex(fields=['search_vector'], name='agadmator_v_search__8d5e27_gin'),
        ),
    ]
