# Generated by Django 2.1.3 on 2018-11-05 16:28

from django.db import migrations, models




class Migration(migrations.Migration):
    dependencies = [
        ('agadmator', '0003_auto_20181105_1613'),
    ]

    operations = [
        migrations.AddField(
            model_name='video',
            name='black_name',
            field=models.CharField(blank=True, max_length=500),
        ),
        migrations.AddField(
            model_name='video',
            name='black_slug',
            field=models.CharField(blank=True, db_index=True, max_length=500),
        ),
        migrations.AddField(
            model_name='video',
            name='error',
            field=models.BooleanField(db_index=True, default=False),
        ),
        migrations.AddField(
            model_name='video',
            name='tournament_id',
            field=models.BigIntegerField(blank=True, db_index=True, null=True),
        ),
        migrations.AddField(
            model_name='video',
            name='tournament_name',
            field=models.CharField(blank=True, max_length=500),
        ),
        migrations.AddField(
            model_name='video',
            name='white_name',
            field=models.CharField(blank=True, max_length=500),
        ),
        migrations.AddField(
            model_name='video',
            name='white_slug',
            field=models.SlugField(blank=True, max_length=500),
        ),
        migrations.AddField(
            model_name='video',
            name='year',
            field=models.PositiveIntegerField(blank=True, null=True),
        ),

    ]
