# Generated by Django 2.1.3 on 2018-11-05 08:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('agadmator', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='video',
            name='engine',
            field=models.BooleanField(db_index=True, default=False),
        ),
        migrations.AddField(
            model_name='video',
            name='error',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='video',
            name='ignore',
            field=models.BooleanField(db_index=True, default=False),
        ),
        migrations.AddField(
            model_name='video',
            name='stream',
            field=models.BooleanField(db_index=True, default=False),
        ),
    ]
