# Generated by Django 2.1.3 on 2018-11-05 16:13

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('agadmator', '0002_auto_20181105_0808'),
    ]

    operations = [
        migrations.RenameField(
            model_name='video',
            old_name='error',
            new_name='error_message',
        ),
    ]
