{% extends 'agadmator/base.html' %}

{% block content %}
  <h2>Year {{ year }}</h2>
  <hr>
  <div class="row">
    {% for video in videos %}
      {% include 'agadmator/_video_card.html' with video=video %}
    {% endfor %}
  </div>

{% endblock content %}